
from setuptools import setup, find_packages

setup(
    name='coinhone',
    version='0.1',
    author='wade',
    author_email='weishadev@gmail.com',
    description='coinhone of lucky',
    packages=find_packages()
)